@@ -3,7 +3,11 @@ import os
 import requests
 
 PYTHON_VERSIONS = {
-    "3.6": "python36", "3.7": "python37", "3.8": "python38", "3.9": "python39",
+    "3.6": "python36",
+    "3.7": "python37",
+    "3.8": "python38",
+    "3.9": "python39",
+    "3.10": "python310",
 }
 
 
@@ -49,5 +53,3 @@ def call_api(url, method, **kwargs):
             f"Authentication error {response.status_code} calling API: {response.text}"
         )
     return response
-
-
