@@ -1,4 +1,4 @@
-#!/usr/bin/python3.5
+#!/usr/bin/python3.6
 """Set the HTTPS certificate and private key for a website to the contents of two files, and reload the site.
 
 Usage:
@@ -25,13 +25,13 @@ from pythonanywhere.snakesay import snakesay
 
 def main(domain_name, certificate_file, private_key_file, suppress_reload):
     if not os.path.exists(certificate_file):
-        print("Could not find certificate file {certificate_file}".format(certificate_file=certificate_file))
+        print(f"Could not find certificate file {certificate_file}")
         sys.exit(1)
     with open(certificate_file, "r") as f:
         certificate = f.read()
 
     if not os.path.exists(private_key_file):
-        print("Could not find private key file {private_key_file}".format(private_key_file=private_key_file))
+        print(f"Could not find private key file {private_key_file}")
         sys.exit(1)
     with open(private_key_file, "r") as f:
         private_key = f.read()
